==> chaosmesh-model-6.6.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosPatchActionsFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosPatchActionsFluentImpl<A extends PodHttpChaosPatchActionsFluent<A>> extends BaseFluent<A> implements PodHttpChaosPatchActionsFluent<A>{
  public PodHttpChaosPatchActionsFluentImpl() {
  }
  public PodHttpChaosPatchActionsFluentImpl(PodHttpChaosPatchActions instance) {
    this.withBody(instance.getBody()); 
    this.withHeaders(instance.getHeaders()); 
    this.withQueries(instance.getQueries()); 
  }
  private PodHttpChaosPatchBodyActionBuilder body;
  private List<List<String>> headers = new ArrayList<List<String>>();
  private List<List<String>> queries = new ArrayList<List<String>>();
  
  /**
   * This method has been deprecated, please use method buildBody instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosPatchBodyAction getBody() {
    return this.body!=null ?this.body.build():null;
  }
  public PodHttpChaosPatchBodyAction buildBody() {
    return this.body!=null ?this.body.build():null;
  }
  public A withBody(PodHttpChaosPatchBodyAction body) {
    _visitables.get("body").remove(this.body);
    if (body!=null){ this.body= new PodHttpChaosPatchBodyActionBuilder(body); _visitables.get("body").add(this.body);} else { this.body = null; _visitables.get("body").remove(this.body); } return (A) this;
  }
  public Boolean hasBody() {
    return this.body != null;
  }
  public A withNewBody(String type,String value) {
    return (A)withBody(new PodHttpChaosPatchBodyAction(type, value));
  }
  public PodHttpChaosPatchActionsFluent.BodyNested<A> withNewBody() {
    return new PodHttpChaosPatchActionsFluentImpl.BodyNestedImpl();
  }
  public PodHttpChaosPatchActionsFluent.BodyNested<A> withNewBodyLike(PodHttpChaosPatchBodyAction item) {
    return new PodHttpChaosPatchActionsFluentImpl.BodyNestedImpl(item);
  }
  public PodHttpChaosPatchActionsFluent.BodyNested<A> editBody() {
    return withNewBodyLike(getBody());
  }
  public PodHttpChaosPatchActionsFluent.BodyNested<A> editOrNewBody() {
    return withNewBodyLike(getBody() != null ? getBody(): new PodHttpChaosPatchBodyActionBuilder().build());
  }
  public PodHttpChaosPatchActionsFluent.BodyNested<A> editOrNewBodyLike(PodHttpChaosPatchBodyAction item) {
    return withNewBodyLike(getBody() != null ? getBody(): item);
  }
  public A addToHeaders(Integer index,List<String> item) {
    if (this.headers == null) {this.headers = new ArrayList<List<String>>();}
    this.headers.add(index, item);
    return (A)this;
  }
  public A setToHeaders(Integer index,List<String> item) {
    if (this.headers == null) {this.headers = new ArrayList<List<String>>();}
    this.headers.set(index, item); return (A)this;
  }
  public A addToHeaders(List<String>... items) {
    if (this.headers == null) {this.headers = new ArrayList<List<String>>();}
    for (List<String> item : items) {this.headers.add(item);} return (A)this;
  }
  public A addAllToHeaders(Collection<List<String>> items) {
    if (this.headers == null) {this.headers = new ArrayList<List<String>>();}
    for (List<String> item : items) {this.headers.add(item);} return (A)this;
  }
  public A removeFromHeaders(List<String>... items) {
    for (List<String> item : items) {if (this.headers!= null){ this.headers.remove(item);}} return (A)this;
  }
  public A removeAllFromHeaders(Collection<List<String>> items) {
    for (List<String> item : items) {if (this.headers!= null){ this.headers.remove(item);}} return (A)this;
  }
  public List<List<String>> getHeaders() {
    return this.headers;
  }
  public List<String> getHeader(Integer index) {
    return this.headers.get(index);
  }
  public List<String> getFirstHeader() {
    return this.headers.get(0);
  }
  public List<String> getLastHeader() {
    return this.headers.get(headers.size() - 1);
  }
  public List<String> getMatchingHeader(Predicate<List<String>> predicate) {
    for (List<String> item: headers) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingHeader(Predicate<List<String>> predicate) {
    for (List<String> item: headers) { if(predicate.test(item)){ return true;} } return false;
  }
  public <E>A withHeaders(List<List<String>> headers) {
    if (headers != null) {this.headers = new ArrayList(); for (List<String> item : headers){this.addToHeaders(item);}} else { this.headers = null;} return (A) this;
  }
  public A withHeaders(List<String>... headers) {
    if (this.headers != null) {this.headers.clear();}
    if (headers != null) {for (List<String> item :headers){ this.addToHeaders(item);}} return (A) this;
  }
  public Boolean hasHeaders() {
    return headers != null && !headers.isEmpty();
  }
  public A addToQueries(Integer index,List<String> item) {
    if (this.queries == null) {this.queries = new ArrayList<List<String>>();}
    this.queries.add(index, item);
    return (A)this;
  }
  public A setToQueries(Integer index,List<String> item) {
    if (this.queries == null) {this.queries = new ArrayList<List<String>>();}
    this.queries.set(index, item); return (A)this;
  }
  public A addToQueries(List<String>... items) {
    if (this.queries == null) {this.queries = new ArrayList<List<String>>();}
    for (List<String> item : items) {this.queries.add(item);} return (A)this;
  }
  public A addAllToQueries(Collection<List<String>> items) {
    if (this.queries == null) {this.queries = new ArrayList<List<String>>();}
    for (List<String> item : items) {this.queries.add(item);} return (A)this;
  }
  public A removeFromQueries(List<String>... items) {
    for (List<String> item : items) {if (this.queries!= null){ this.queries.remove(item);}} return (A)this;
  }
  public A removeAllFromQueries(Collection<List<String>> items) {
    for (List<String> item : items) {if (this.queries!= null){ this.queries.remove(item);}} return (A)this;
  }
  public List<List<String>> getQueries() {
    return this.queries;
  }
  public List<String> getQuery(Integer index) {
    return this.queries.get(index);
  }
  public List<String> getFirstQuery() {
    return this.queries.get(0);
  }
  public List<String> getLastQuery() {
    return this.queries.get(queries.size() - 1);
  }
  public List<String> getMatchingQuery(Predicate<List<String>> predicate) {
    for (List<String> item: queries) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingQuery(Predicate<List<String>> predicate) {
    for (List<String> item: queries) { if(predicate.test(item)){ return true;} } return false;
  }
  public <E>A withQueries(List<List<String>> queries) {
    if (queries != null) {this.queries = new ArrayList(); for (List<String> item : queries){this.addToQueries(item);}} else { this.queries = null;} return (A) this;
  }
  public A withQueries(List<String>... queries) {
    if (this.queries != null) {this.queries.clear();}
    if (queries != null) {for (List<String> item :queries){ this.addToQueries(item);}} return (A) this;
  }
  public Boolean hasQueries() {
    return queries != null && !queries.isEmpty();
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodHttpChaosPatchActionsFluentImpl that = (PodHttpChaosPatchActionsFluentImpl) o;
    if (body != null ? !body.equals(that.body) :that.body != null) return false;
    if (headers != null ? !headers.equals(that.headers) :that.headers != null) return false;
    if (queries != null ? !queries.equals(that.queries) :that.queries != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(body,  headers,  queries,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (body != null) { sb.append("body:"); sb.append(body + ","); }
    if (headers != null && !headers.isEmpty()) { sb.append("headers:"); sb.append(headers + ","); }
    if (queries != null && !queries.isEmpty()) { sb.append("queries:"); sb.append(queries); }
    sb.append("}");
    return sb.toString();
  }
  class BodyNestedImpl<N> extends PodHttpChaosPatchBodyActionFluentImpl<PodHttpChaosPatchActionsFluent.BodyNested<N>> implements PodHttpChaosPatchActionsFluent.BodyNested<N>,Nested<N>{
    BodyNestedImpl(PodHttpChaosPatchBodyAction item) {
      this.builder = new PodHttpChaosPatchBodyActionBuilder(this, item);
    }
    BodyNestedImpl() {
      this.builder = new PodHttpChaosPatchBodyActionBuilder(this);
    }
    PodHttpChaosPatchBodyActionBuilder builder;
    public N and() {
      return (N) PodHttpChaosPatchActionsFluentImpl.this.withBody(builder.build());
    }
    public N endBody() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosPatchActionsFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosPatchActionsFluentImpl<A extends PodHttpChaosPatchActionsFluent<A>> extends BaseFluent<A> implements PodHttpChaosPatchActionsFluent<A>{
  public PodHttpChaosPatchActionsFluentImpl() {
  }
  public PodHttpChaosPatchActionsFluentImpl(PodHttpChaosPatchActions instance) {
    if (instance != null) {
      this.withBody(instance.getBody());
      this.withHeaders(instance.getHeaders());
      this.withQueries(instance.getQueries());
    }
  }
  private PodHttpChaosPatchBodyActionBuilder body;
  private List<List<String>> headers = new ArrayList<List<String>>();
  private List<List<String>> queries = new ArrayList<List<String>>();
  
  /**
   * This method has been deprecated, please use method buildBody instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosPatchBodyAction getBody() {
    return this.body!=null ?this.body.build():null;
  }
  public PodHttpChaosPatchBodyAction buildBody() {
    return this.body!=null ?this.body.build():null;
  }
  public A withBody(PodHttpChaosPatchBodyAction body) {
    _visitables.get("body").remove(this.body);
    if (body!=null){ this.body= new PodHttpChaosPatchBodyActionBuilder(body); _visitables.get("body").add(this.body);} else { this.body = null; _visitables.get("body").remove(this.body); } return (A) this;
  }
  public Boolean hasBody() {
    return this.body != null;
  }
  public A withNewBody(String type,String value) {
    return (A)withBody(new PodHttpChaosPatchBodyAction(type, value));
  }
  public PodHttpChaosPatchActionsFluentImpl.BodyNested<A> withNewBody() {
    return new PodHttpChaosPatchActionsFluentImpl.BodyNestedImpl();
  }
  public PodHttpChaosPatchActionsFluentImpl.BodyNested<A> withNewBodyLike(PodHttpChaosPatchBodyAction item) {
    return new PodHttpChaosPatchActionsFluentImpl.BodyNestedImpl(item);
  }
  public PodHttpChaosPatchActionsFluentImpl.BodyNested<A> editBody() {
    return withNewBodyLike(getBody());
  }
  public PodHttpChaosPatchActionsFluentImpl.BodyNested<A> editOrNewBody() {
    return withNewBodyLike(getBody() != null ? getBody(): new PodHttpChaosPatchBodyActionBuilder().build());
  }
  public PodHttpChaosPatchActionsFluentImpl.BodyNested<A> editOrNewBodyLike(PodHttpChaosPatchBodyAction item) {
    return withNewBodyLike(getBody() != null ? getBody(): item);
  }
  public A addToHeaders(int index,List<String> item) {
    if (this.headers == null) {this.headers = new ArrayList<List<String>>();}
    this.headers.add(index, item);
    return (A)this;
  }
  public A setToHeaders(int index,List<String> item) {
    if (this.headers == null) {this.headers = new ArrayList<List<String>>();}
    this.headers.set(index, item); return (A)this;
  }
  public A addToHeaders(List<String>... items) {
    if (this.headers == null) {this.headers = new ArrayList<List<String>>();}
    for (List<String> item : items) {this.headers.add(item);} return (A)this;
  }
  public A addAllToHeaders(Collection<List<String>> items) {
    if (this.headers == null) {this.headers = new ArrayList<List<String>>();}
    for (List<String> item : items) {this.headers.add(item);} return (A)this;
  }
  public A removeFromHeaders(List<String>... items) {
    for (List<String> item : items) {if (this.headers!= null){ this.headers.remove(item);}} return (A)this;
  }
  public A removeAllFromHeaders(Collection<List<String>> items) {
    for (List<String> item : items) {if (this.headers!= null){ this.headers.remove(item);}} return (A)this;
  }
  public List<List<String>> getHeaders() {
    return this.headers;
  }
  public List<String> getHeader(int index) {
    return this.headers.get(index);
  }
  public List<String> getFirstHeader() {
    return this.headers.get(0);
  }
  public List<String> getLastHeader() {
    return this.headers.get(headers.size() - 1);
  }
  public List<String> getMatchingHeader(Predicate<List<String>> predicate) {
    for (List<String> item: headers) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingHeader(Predicate<List<String>> predicate) {
    for (List<String> item: headers) { if(predicate.test(item)){ return true;} } return false;
  }
  public <E>A withHeaders(List<List<String>> headers) {
    if (headers != null) {this.headers = new ArrayList(); for (List<String> item : headers){this.addToHeaders(item);}} else { this.headers = null;} return (A) this;
  }
  public A withHeaders(List<String>... headers) {
    if (this.headers != null) {this.headers.clear(); _visitables.remove("headers"); }
    if (headers != null) {for (List<String> item :headers){ this.addToHeaders(item);}} return (A) this;
  }
  public Boolean hasHeaders() {
    return headers != null && !headers.isEmpty();
  }
  public A addToQueries(int index,List<String> item) {
    if (this.queries == null) {this.queries = new ArrayList<List<String>>();}
    this.queries.add(index, item);
    return (A)this;
  }
  public A setToQueries(int index,List<String> item) {
    if (this.queries == null) {this.queries = new ArrayList<List<String>>();}
    this.queries.set(index, item); return (A)this;
  }
  public A addToQueries(List<String>... items) {
    if (this.queries == null) {this.queries = new ArrayList<List<String>>();}
    for (List<String> item : items) {this.queries.add(item);} return (A)this;
  }
  public A addAllToQueries(Collection<List<String>> items) {
    if (this.queries == null) {this.queries = new ArrayList<List<String>>();}
    for (List<String> item : items) {this.queries.add(item);} return (A)this;
  }
  public A removeFromQueries(List<String>... items) {
    for (List<String> item : items) {if (this.queries!= null){ this.queries.remove(item);}} return (A)this;
  }
  public A removeAllFromQueries(Collection<List<String>> items) {
    for (List<String> item : items) {if (this.queries!= null){ this.queries.remove(item);}} return (A)this;
  }
  public List<List<String>> getQueries() {
    return this.queries;
  }
  public List<String> getQuery(int index) {
    return this.queries.get(index);
  }
  public List<String> getFirstQuery() {
    return this.queries.get(0);
  }
  public List<String> getLastQuery() {
    return this.queries.get(queries.size() - 1);
  }
  public List<String> getMatchingQuery(Predicate<List<String>> predicate) {
    for (List<String> item: queries) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingQuery(Predicate<List<String>> predicate) {
    for (List<String> item: queries) { if(predicate.test(item)){ return true;} } return false;
  }
  public <E>A withQueries(List<List<String>> queries) {
    if (queries != null) {this.queries = new ArrayList(); for (List<String> item : queries){this.addToQueries(item);}} else { this.queries = null;} return (A) this;
  }
  public A withQueries(List<String>... queries) {
    if (this.queries != null) {this.queries.clear(); _visitables.remove("queries"); }
    if (queries != null) {for (List<String> item :queries){ this.addToQueries(item);}} return (A) this;
  }
  public Boolean hasQueries() {
    return queries != null && !queries.isEmpty();
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodHttpChaosPatchActionsFluentImpl that = (PodHttpChaosPatchActionsFluentImpl) o;
    if (!java.util.Objects.equals(body, that.body)) return false;

    if (!java.util.Objects.equals(headers, that.headers)) return false;

    if (!java.util.Objects.equals(queries, that.queries)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(body,  headers,  queries,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (body != null) { sb.append("body:"); sb.append(body + ","); }
    if (headers != null && !headers.isEmpty()) { sb.append("headers:"); sb.append(headers + ","); }
    if (queries != null && !queries.isEmpty()) { sb.append("queries:"); sb.append(queries); }
    sb.append("}");
    return sb.toString();
  }
  class BodyNestedImpl<N> extends PodHttpChaosPatchBodyActionFluentImpl<PodHttpChaosPatchActionsFluentImpl.BodyNested<N>> implements PodHttpChaosPatchActionsFluentImpl.BodyNested<N>,Nested<N>{
    BodyNestedImpl(PodHttpChaosPatchBodyAction item) {
      this.builder = new PodHttpChaosPatchBodyActionBuilder(this, item);
    }
    BodyNestedImpl() {
      this.builder = new PodHttpChaosPatchBodyActionBuilder(this);
    }
    PodHttpChaosPatchBodyActionBuilder builder;
    public N and() {
      return (N) PodHttpChaosPatchActionsFluentImpl.this.withBody(builder.build());
    }
    public N endBody() {
      return and();
    }
    
  }
  
}
